# = replaced with <-
a <- 3
data_frame(a = 3)

# semicolon
a
b
c
d


# quotes
"text with 'quotes'"
'text with "quotes"'



# adding brackets in pipes
a %>%
  b() %>%
  c()

# adding brackets in pipes combined with line breaks
a %>%
  b() %>%
  c()
